@@ -2,7 +2,7 @@ package PITA::XML;
 
 # See POD at end for docs.
 
-use 5.005;
+use 5.006;
 use strict;
 use Carp                    ();
 use Params::Util            ':ALL';
@@ -24,7 +24,7 @@ use XML::Validator::Schema  ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.40';
+	$VERSION = '0.41';
 }
 
 # The XML Schema File
@@ -46,7 +46,7 @@ BEGIN {
 		'perl5.make'  => 1,
 		'perl5.build' => 1,
 		'perl6'       => 1,
-		);
+	);
 }
 
 # Load the various classes
@@ -159,6 +159,12 @@ sub _DISTNAME {
 	($distname =~ /^[a-z]\w*(?:\-[a-z]\w*)+$/is) ? $distname : undef;
 }
 
+sub _GUID {
+	my $class = shift;
+	my $guid  = _STRING(shift) or return undef;
+	($guid =~ /^[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}$/) ? $guid : undef;
+}
+
 1;
 
 __END__
@@ -200,7 +206,7 @@ The Perl Image-based Testing Architecture (L<http://ali.as/pita/>)
 
 =head1 COPYRIGHT
 
-Copyright 2005 - 2006 Adam Kennedy.
+Copyright 2005 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
